@@ -1,4 +1,4 @@
-/* C++ code produced by gperf version 3.0.4 */
+/* C++ code produced by gperf version 3.1 */
 /* Command-line: /usr/bin/gperf --compare-strncmp --switch=1 --struct-type libgearman/error_code.gperf  */
 /* Computed positions: -k'1,$' */
 
@@ -26,7 +26,7 @@
       && ('w' == 119) && ('x' == 120) && ('y' == 121) && ('z' == 122) \
       && ('{' == 123) && ('|' == 124) && ('}' == 125) && ('~' == 126))
 /* The character set is not based on ISO-646.  */
-#error "gperf generated tables don't work with this execution character set. Please report a bug to <bug-gnu-gperf@gnu.org>."
+#error "gperf generated tables don't work with this execution character set. Please report a bug to <bug-gperf@gnu.org>."
 #endif
 
 #line 10 "libgearman/error_code.gperf"
@@ -109,7 +109,7 @@ static unsigned char gperf_downcase[256] =
 #ifndef GPERF_CASE_MEMCMP
 #define GPERF_CASE_MEMCMP 1
 static int
-gperf_case_memcmp (register const char *s1, register const char *s2, register unsigned int n)
+gperf_case_memcmp (const char *s1, const char *s2, size_t n)
 {
   for (; n > 0;)
     {
@@ -129,13 +129,13 @@ gperf_case_memcmp (register const char *s1, register const char *s2, register un
 class String2gearman_return_t
 {
 private:
-  static inline unsigned int hash (const char *str, unsigned int len);
+  static inline unsigned int hash (const char *str, size_t len);
 public:
-  static const struct error_code_st *in_word_set (const char *str, unsigned int len);
+  static const struct error_code_st *in_word_set (const char *str, size_t len);
 };
 
 inline unsigned int
-String2gearman_return_t::hash (register const char *str, register unsigned int len)
+String2gearman_return_t::hash (const char *str, size_t len)
 {
   static const unsigned char asso_values[] =
     {
@@ -166,11 +166,11 @@ String2gearman_return_t::hash (register const char *str, register unsigned int l
       104, 104, 104, 104, 104, 104, 104, 104, 104, 104,
       104, 104, 104, 104, 104, 104
     };
-  return len + asso_values[(unsigned char)str[len - 1]] + asso_values[(unsigned char)str[0]];
+  return len + asso_values[static_cast<unsigned char>(str[len - 1])] + asso_values[static_cast<unsigned char>(str[0])];
 }
 
 const struct error_code_st *
-String2gearman_return_t::in_word_set (register const char *str, register unsigned int len)
+String2gearman_return_t::in_word_set (const char *str, size_t len)
 {
   enum
     {
@@ -293,11 +293,11 @@ String2gearman_return_t::in_word_set (register const char *str, register unsigne
 
   if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH)
     {
-      register int key = hash (str, len);
+      unsigned int key = hash (str, len);
 
       if (key <= MAX_HASH_VALUE && key >= MIN_HASH_VALUE)
         {
-          register const struct error_code_st *resword;
+          const struct error_code_st *resword;
 
           switch (key - 7)
             {
@@ -676,7 +676,7 @@ String2gearman_return_t::in_word_set (register const char *str, register unsigne
           return 0;
         compare:
           {
-            register const char *s = resword->name;
+            const char *s = resword->name;
 
             if ((((unsigned char)*str ^ (unsigned char)*s) & ~32) == 0 && !gperf_case_memcmp (str, s, len))
               return resword;
